@@ -83,11 +83,13 @@ sub worker_body {
           }
 
           # 1392 check for any of the same job running already
-          foreach my $p ( @{$t->table} ) {
-              if ($p->cmndline
-                    and $p->cmndline =~ m/nd2: #\d+ poll: #\d+: ${display_name}/) {
-                  debug "mgr ($wid): duplicate running job detected: $display_name";
-                  next JOB;
+          if ($job->device) {
+              foreach my $p ( @{$t->table} ) {
+                  if ($p->cmndline
+                        and $p->cmndline =~ m/nd2: #\d+ poll: #\d+: ${display_name}/) {
+                      debug "mgr ($wid): duplicate running job detected: $display_name";
+                      next JOB;
+                  }
               }
           }
 
