@@ -5,7 +5,7 @@ use App::Netdisco::Worker::Plugin;
 use aliased 'App::Netdisco::Worker::Status';
 
 use App::Netdisco::Transport::SNMP ();
-use App::Netdisco::Util::Device qw/get_device is_discoverable/;
+use App::Netdisco::Util::Device qw/get_device is_discoverable match_to_setting/;
 use App::Netdisco::Util::Permission 'acl_matches';
 use App::Netdisco::JobQueue 'jq_insert';
 use Dancer::Plugin::DBIC 'schema';
@@ -144,8 +144,8 @@ sub store_neighbors {
   # allow fallback from v6 to try v4
   my %success_with_index = ();
 
-  NEIGHBOR: foreach my $pair ((sort { $a->key <=> $b->key } pairs %c_ipv6),
-                              (sort { $a->key <=> $b->key } pairs %$c_ip)) {
+  NEIGHBOR: foreach my $pair ((sort { $a->key cmp $b->key } pairs %c_ipv6),
+                              (sort { $a->key cmp $b->key } pairs %$c_ip)) {
 
       my ($entry, $c_ip_entry) = (@$pair);
       next unless defined $entry and defined $c_ip_entry;
@@ -199,6 +199,12 @@ sub store_neighbors {
           next NEIGHBOR;
       }
 
+      if ($remote_type and match_to_setting($remote_type, 'neighbor_no_type')) {
+          debug sprintf ' [%s] neigh - %s has type %s matching neighbor_no_type - skipping',
+            $device->ip, $remote_ip, $remote_type;
+          next NEIGHBOR;
+      }
+
       # a bunch of heuristics to search known devices if we do not have a
       # useable remote IP...
 
